summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorFatih Degirmenci <fatih.degirmenci@ericsson.com>2015-12-22 12:27:26 +0100
committerFatih Degirmenci <fatih.degirmenci@ericsson.com>2015-12-22 14:16:38 +0100
commit8722b62ef61bd9d85eb1717d32ffeb13da0a6056 (patch)
treeab331f95cb95386a72900acd8ff913ae353e9ab8
parent3ab65d1960a92cde21ec764fdc57b7347527e96e (diff)
Adjustments for fuel jobs
- Disable build avoidance for non-daily fuel jobs - Enable throttling and disable concurrency to make sure we do not start extra builds on same pod. Change-Id: Iff3c609fdf77beb08480d6e265e1d2f134cb1230 Signed-off-by: Fatih Degirmenci <fatih.degirmenci@ericsson.com>
-rwxr-xr-xjjb/fuel/fuel-build.sh20
-rw-r--r--jjb/fuel/fuel-ci-jobs.yml22
2 files changed, 34 insertions, 8 deletions
diff --git a/jjb/fuel/fuel-ci-jobs.yml b/jjb/fuel/fuel-ci-jobs.yml
index fa0f666d6..bcc3248c1 100644
--- a/jjb/fuel/fuel-ci-jobs.yml
+++ b/jjb/fuel/fuel-ci-jobs.yml
@@ -68,6 +68,12 @@
concurrent: false
+ properties:
+ - throttle:
+ enabled: true
+ max-total: 1
+ max-per-node: 1
+
wrappers:
- build-name:
name: '$BUILD_NUMBER - SDN: $SDN_CONTROLLER Feature: $OPNFV_FEATURE'
@@ -129,6 +135,14 @@
- job-template:
name: 'fuel-build-{pod}-daily-{stream}'
+ concurrent: false
+
+ properties:
+ - throttle:
+ enabled: true
+ max-total: 1
+ max-per-node: 1
+
parameters:
- project-parameter:
project: '{project}'
@@ -163,6 +177,14 @@
- job-template:
name: 'fuel-deploy-{pod}-daily-{stream}'
+ concurrent: false
+
+ properties:
+ - throttle:
+ enabled: true
+ max-total: 1
+ max-per-node: 1
+
parameters:
- project-parameter:
project: '{project}'
diff --git a/jjb/fuel/fuel-build.sh b/jjb/fuel/fuel-build.sh
index 6ccfb6f0e..1602078d1 100755
--- a/jjb/fuel/fuel-build.sh
+++ b/jjb/fuel/fuel-build.sh
@@ -5,16 +5,20 @@ set -o pipefail
cd $WORKSPACE
-# check to see if we already have an artifact on artifacts.opnfv.org
-# for this commit
-echo "Checking to see if we already built and stored Fuel ISO for this commit"
+if [[ "$JOB_NAME" =~ "daily" ]]; then
+ # check to see if we already have an artifact on artifacts.opnfv.org
+ # for this commit during daily builds
+ echo "Checking to see if we already built and stored Fuel ISO for this commit"
-LATEST_ISO_PROPERTIES=$WORKSPACE/latest.iso.properties
-curl -s -o $LATEST_ISO_PROPERTIES http://$GS_URL/latest.properties 2>/dev/null
+ LATEST_ISO_PROPERTIES=$WORKSPACE/latest.iso.properties
+ curl -s -o $LATEST_ISO_PROPERTIES http://$GS_URL/latest.properties 2>/dev/null
-# get metadata of latest ISO
-LATEST_ISO_SHA1=$(grep OPNFV_GIT_SHA1 $LATEST_ISO_PROPERTIES | cut -d'=' -f2)
-LATEST_ISO_URL=$(grep OPNFV_ARTIFACT_URL $LATEST_ISO_PROPERTIES | cut -d'=' -f2)
+ # get metadata of latest ISO
+ LATEST_ISO_SHA1=$(grep OPNFV_GIT_SHA1 $LATEST_ISO_PROPERTIES | cut -d'=' -f2)
+ LATEST_ISO_URL=$(grep OPNFV_ARTIFACT_URL $LATEST_ISO_PROPERTIES | cut -d'=' -f2)
+else
+ LATEST_ISO_SHA1=none
+fi
# get current SHA1
CURRENT_SHA1=$(git rev-parse HEAD)